CategoryPackAttribute filterSetFromJson(dynamic str) =>
    (CategoryPackAttribute.fromJson(str));

class CategoryPackAttribute {
  late final List<Category> category;
  late final List<Attribute> attribute;
  late final PriceRange? priceRange;
  late final String sTypename;

  CategoryPackAttribute(
      {required this.category,
      required this.attribute,
      required this.priceRange,
      required this.sTypename});

  CategoryPackAttribute.fromJson(Map<String, dynamic> json) {
    if (json['category'] != null) {
      category = [];
      json['category'].forEach((v) {
        category.add(new Category.fromJson(v));
      });
    }
    if (json['attribute'] != null) {
      attribute = [];
      json['attribute'].forEach((v) {
        attribute.add(new Attribute.fromJson(v));
      });
    }
    priceRange = json['priceRange'] != null
        ? new PriceRange.fromJson(json['priceRange'])
        : null;
    sTypename = json['__typename'];
  }
}

class Category {
  late final String sId;
  late final String categoryName;
  late final String categoryDescription;
  late final String sTypename;

  Category(
      {required this.sId,
      required this.categoryName,
      required this.categoryDescription,
      required this.sTypename});

  Category.fromJson(Map<String, dynamic> json) {
    sId = json['_id'];
    categoryName = json['categoryName'];
    categoryDescription = json['categoryDescription'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['_id'] = this.sId;
    data['categoryName'] = this.categoryName;
    data['categoryDescription'] = this.categoryDescription;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class Attribute {
  late final String attributeFieldId;
  late final bool fieldEnable;
  late final String fieldSetting;
  late final String labelName;
  late final String fieldName;
  late final Null checked;
  late final List<FieldValue> fieldValue;
  late final String sTypename;

  Attribute(
      {required this.attributeFieldId,
      required this.fieldEnable,
      required this.fieldSetting,
      required this.labelName,
      required this.fieldName,
      required this.checked,
      required this.fieldValue,
      required this.sTypename});

  Attribute.fromJson(Map<String, dynamic> json) {
    attributeFieldId = json['attributeFieldId'];
    fieldEnable = json['fieldEnable'];
    fieldSetting = json['fieldSetting'];
    labelName = json['labelName'];
    fieldName = json['fieldName'];
    checked = json['checked'];
    if (json['fieldValue'] != null) {
      fieldValue = [];
      json['fieldValue'].forEach((v) {
        fieldValue.add(new FieldValue.fromJson(v));
      });
    }
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['attributeFieldId'] = this.attributeFieldId;
    data['fieldEnable'] = this.fieldEnable;
    data['fieldSetting'] = this.fieldSetting;
    data['labelName'] = this.labelName;
    data['fieldName'] = this.fieldName;
    data['checked'] = this.checked;
    if (this.fieldValue != null) {
      data['fieldValue'] = this.fieldValue.map((v) => v.toJson()).toList();
    }
    data['__typename'] = this.sTypename;
    return data;
  }
}

class FieldValue {
  late final String attributeFieldValueId;
  late final String attributeFieldValue;
  late final Null checked;
  late final String sTypename;

  FieldValue(
      {required this.attributeFieldValueId,
      required this.attributeFieldValue,
      required this.checked,
      required this.sTypename});

  FieldValue.fromJson(Map<String, dynamic> json) {
    attributeFieldValueId = json['attributeFieldValueId'];
    attributeFieldValue = json['attributeFieldValue'];
    checked = json['checked'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['attributeFieldValueId'] = this.attributeFieldValueId;
    data['attributeFieldValue'] = this.attributeFieldValue;
    data['checked'] = this.checked;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class PriceRange {
  late final int low;
  late final int high;
  late final int selectedLow;
  late final int selectedHigh;
  late final String sTypename;

  PriceRange(
      {required this.low,
      required this.high,
      required this.selectedLow,
      required this.selectedHigh,
      required this.sTypename});

  PriceRange.fromJson(Map<String, dynamic> json) {
    low = json['low'];
    high = json['high'];
    selectedLow = json['selectedLow'];
    selectedHigh = json['selectedHigh'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['low'] = this.low;
    data['high'] = this.high;
    data['selectedLow'] = this.selectedLow;
    data['selectedHigh'] = this.selectedHigh;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class SelectedFilter {
  String fieldName;
  String fieldValue;

  SelectedFilter({
    required this.fieldName,
    required this.fieldValue,
  });

  SelectedFilter.fromJson(dynamic json)
      : fieldName = json.fieldName,
        fieldValue = json.fieldValue;

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['fieldName'] = this.fieldName;
    data['fieldValue'] = this.fieldValue;

    return data;
  }
}
