import 'package:graphql_flutter/graphql_flutter.dart';

import '../../GraphQLConfiguration.dart';
import 'order_List_model.dart';
import './order_single_model.dart';

class OrderRepo {
  var graphQLConfiguration;

  var orderList;
  var singleOrder;
  var checkCancellation;
  OrderRepo() {
    graphQLConfiguration = GraphQLConfiguration();
  }

  Future getOrderList(String userId, int pageNo, int limit) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var orderListGql = """ 
             query getUserOrder(\$userId: String, \$pageNo: Int, \$limit: Int) {
            getUserOrder(userId: \$userId, pageNo: \$pageNo, limit: \$limit) {
              order {
                orderId
                orderDate
                orderStatus
                totalAmount
                shippingFees
                _id
                __typename
              }
              currentPage
              totalPages
              count
              __typename
            }
          }
            """;

    final vble = {"userId": userId, "pageNo": pageNo, "limit": limit};
    QueryResult result = await _client.query(QueryOptions(
      document: gql(orderListGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    if (!result.hasException) {
      var orderListModel = result.data!['getUserOrder'];

      if (orderListModel != null && orderListModel.length > 0) {
        orderList = orderListFromJson(orderListModel);
        return orderList;
      }
    }
    return orderList;
  }

  Future getSingleOrder(String id) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var orderGql = """ 
             query getSingleOrder(\$id: String) {
              getSingleOrder(id: \$id) {
                _id
                orderDate
                orderId
                bookingId
                shippingFees
                paymentStatus
                billingAddress {
                  contactName
                  companyName
                  emailId
                  mobileNumber
                  address
                  city
                  state
                  pincode
                  __typename
                }
                shippingAddress {
                  contactName
                  companyName
                  emailId
                  mobileNumber
                  address
                  city
                  state
                  pincode
                  __typename
                }
                user {
                  contactName
                  mobileNumber
                  emailId
                  userId
                  __typename
                }
                subTotal
                totalGst
                totalAmount
                orderStatus
                orderItem {
                  quantity
                  comments
                  variant
                  variantValue
                  price
                  piece
                  igst
                  cgst
                  sgst
                  pack {
                    categoryId
                    packSKU
                    packName
                    moq
                    packVariant
                    packImage
                    packId
                    __typename
                  }
                  set {
                    setCode
                    setId
                    sku {
                      setSkuPrice
                      setQuantity
                      skuId
                      sku
                      styleCode
                      variationType
                      b2cSellingPrice
                      b2bSellingPrice
                      mrp
                      discount
                      productName
                      INTsku
                      sizeAttributeSettingId
                      sizeAttributeSettingFieldValueId
                      colorAttributeSettingId
                      colorAttributeSettingFieldValueId
                      sizeAttributeName
                      colorAttributeName
                      sizeAttributeFieldValue
                      colorAttributeFieldValue
                      gstTypeId
                      gstValue
                      __typename
                    }
                    __typename
                  }
                  __typename
                }
                __typename
              }
            }

            """;

    final vble = {
      "id": id,
    };
    QueryResult result = await _client.query(QueryOptions(
      document: gql(orderGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    if (!result.hasException) {
      var singleOrderModel = result.data!['getSingleOrder'];

      if (singleOrderModel != null && singleOrderModel.length > 0) {
        singleOrder = singleOrderFromJson(singleOrderModel);
        return singleOrder;
      }
    }
    return singleOrder;
  }

  Future checkOrderCancellation(String orderId) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var orderCancellationGql = """ 
                          query checkOrderCancellation(\$orderId: String) {
                checkOrderCancellation(orderId: \$orderId) {
                  error
                  message
                  timePeriod
                  hours
                  __typename
                }
              }
            """;

    final vble = {"orderId": orderId};
    QueryResult result = await _client.query(QueryOptions(
      document: gql(orderCancellationGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    if (!result.hasException) {
      var orderCancel = result.data!['checkOrderCancellation'];

      if (orderCancel != null) {
        checkCancellation = orderCancellationFromJson(orderCancel);
        return checkCancellation;
      }
    }
    return checkCancellation;
  }

  Future getCancelContent() async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var orderCancellationGql = """ 
                  query getCancelContent {
                      getCancelContent {
                        reasons {
                          content
                          __typename
                        }
                        message {
                          content
                          __typename
                        }
                        __typename
                      }
                    }
            """;

    QueryResult result = await _client.query(QueryOptions(
      document: gql(orderCancellationGql),
      variables: {},
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    if (!result.hasException) {
      var orderCancelContent = result.data!['getCancelContent'];

      if (orderCancelContent != null) {
        checkCancellation = orderCancelContentFromJson(orderCancelContent);
        return checkCancellation;
      }
    }
    return checkCancellation;
  }
}
