import 'package:b2b_graphql_package/modules/single_pack/single_pack_model.dart';
import 'package:graphql_flutter/graphql_flutter.dart';

import '../../GraphQLConfiguration.dart';

class SinglePackRepo {
  var graphQLConfiguration;

  var singlePack;
  var checkCODByCategoryAvai = false;
  SinglePackRepo() {
    graphQLConfiguration = GraphQLConfiguration();
  }

  Future<SinglePack> getSinglePack(String packId) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var singlePackGql = """ 
                  query getSinglePack(\$packId: String) {
                  getSinglePack(packId: \$packId) {
                    _id
                    packName
                    packDescription
                    moq
                    packVariant
                    packColorLabel {
                      colorId
                      colorName
                      appletName
                      __typename
                    }
                    headSetInformation {
                      setPrice
                      setQuantity
                      mergeAttribute {
                        labelName
                        fieldSetting
                        fieldValue
                        __typename
                      }
                      __typename
                    }
                    packImages {
                      _id
                      packImageName
                      __typename
                    }
                    packOptions {
                      packSetTypeName
                      packSetValue {
                        _id
                        skuIds {
                          skuId {
                            _id
                            sku
                            b2bSellingPrice
                            __typename
                          }
                          setSKUprice
                          __typename
                        }
                        count
                        setPrice
                        setQuantity
                        maximumQuantity
                        setLabelName
                        setColorId
                        setAppletName
                        __typename
                      }
                      __typename
                    }
                    __typename
                  }
                }

            """;

    final vble = {
      "packId": packId,
    };
    QueryResult result = await _client.query(QueryOptions(
      document: gql(singlePackGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    if (!result.hasException) {
      var singlePackSet = result.data!['getSinglePack'];

      if (singlePackSet != null && singlePackSet.length > 0) {
        singlePack = singlePackFromJson(singlePackSet);
      }
      return singlePack;
    }
    return singlePack;
  }

  Future checkCODByCategory(List categoryIds) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var checkCODByCategoryGql = """ 
                  query checkCODByCategory(\$categoryIds: [String]) {
                checkCODByCategory(categoryIds: \$categoryIds)
              }

            """;

    final vble = {
      "categoryIds": categoryIds,
    };
    QueryResult result = await _client.query(QueryOptions(
      document: gql(checkCODByCategoryGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    if (!result.hasException) {
      var checkCOD = result.data!['checkCODByCategory'];

      if (checkCOD != null) {
        checkCODByCategoryAvai = checkCOD;
      }
      return checkCODByCategoryAvai;
    }
    return checkCODByCategoryAvai;
  }
}
